package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@("`0`````````````#`!8````!````````+!@`````````0```````
M`+.@``````!``#@`"0!``!P`&P````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*T`````````K0``
M```````0``````$````&````````K4@```````"]2````````+U(````````
M!4@````````5>````````!```````@````8```````"M6````````+U8````
M````O5@````````"(`````````(@``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````IP````````"G`````````*<``````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*U(````````O4@`````
M``"]2`````````*X`````````K@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`@K;F?A`;"K@U0_K#ZV'VV'[[;<<````$````$```
M``%'3E4```````````,````"````````````````````80````````!D````
M`````````````````````````````````````$$`````````````````````
M`````````#P``````````````````````````````$4`````````'@``````
M`````````````"4`````````'P````````!9````````````````````%@``
M``````!-`````````$X`````````-P````````!;`````````&(`````````
M,``````````^```````````````````````````````@`````````%4`````
M````1@``````````````````````````````40````````!7`````````%0`
M`````````````````````````````&,`````````4```````````````````
M`#8````````````````````Y````````````````````)@````````!<````
M`````$P`````````1P````````````````````,`````````7P``````````
M`````````"<`````````&P``````````````````````````````5@``````
M```D`````````#(`````````*```````````````````````````````#0``
M`````````````````!H`````````````````````````````````````````
M```````````*`````````$@`````````1`````````!``````````%H`````
M````0P``````````````````````````````70````````!3`````````"X`
M````````!P````````!/``````````D`````````.```````````````````
M`#$`````````````````````````````````````````7@````````!2````
M````````````````+P````````!8`````````"H`````````20`````````]
M`````````"P`````````````````````````````````````````````````
M```````````````````````````````````&````````````````````````
M````````````````````````````````````````````````````````````
M``````````!@`````````````````````````````````````````!$`````
M`````````````````````````````````````````````````````````!<`
M```````````````````8````````````````````````````````````````
M````````````%```````````````````````````````$@``````````````
M``````0````````````````````A`````````&$`````````````````````
M``````````````````````````````!*````````````````````````````
M```M`````````!4`````````#```````````````````````````````&0``
M```````.`````````#0````````````````````C````````````````````
M*P`````````S`````````!T`````````"P`````````"````````````````
M``````````````!"````````````````````.P`````````_`````````#H`
M````````(@``````````````````````````````````````````````````
M```````````````````````/`````````!``````````-0``````````````
M``````4`````````'``````````I````````````````````$P``````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````(`````````$L`````````````
M`!$```!*````!`````B$!$`%`!`0((``AH````(H"00@"0``*8((`@2Z11B@
MB`````````!*````3@```%(```!3````60```%H```!;````70```%X`````
M````8````&$```!B````8P``````````']_%;@[OT^HM1][.?)I_:[:;Q2X.
MY/\@#O&-N'S49-4<6''9`<9'XL#C2ZQ\DN.Z+#_EPF!LH?IOBP&SUD,):V;,
MKV?LU45"TW`'B9[B%`V>X\W:[=MB,PN7.@V;G*E_"@*GX4G[X*,`````````
M``````````````````````````````````,```P````````AP```````````
M```"B1(````````````````````````````#"R(`````````````````````
M```````!W1(`````````````````````````````#"``````````````````
M```````````#21$````````````````````````````#AA(`````````````
M```````````````"UA$````````````````````````````#*!(`````````
M```````````````````!#!(````````````````````````````">Q(`````
M```````````````````````"I!(`````````````````````````````KQ(`
M```````````````````````````!?A(````````````````````````````"
MD!(`````````````````````````````?Q(`````````````````````````
M```!!Q(````````````````````````````"1Q(`````````````````````
M```````"W1(`````````````````````````````_!$`````````````````
M```````````"91(````````````````````````````!8A(`````````````
M````````````````WA$````````````````````````````!,!(`````````
M````````````````````O1(````````````````````````````!K!(`````
M```````````````````````"Y!(````````````````````````````"'Q(`
M```````````````````````````!\Q(````````````````````````````!
MF1(````````````````````````````"=!(`````````````````````````
M```"6!(````````````````````````````!I1(`````````````````````
M```````!/A(````````````````````````````"[1(`````````````````
M````````````*"`````````````````````````````",1(`````````````
M```````````````!MQ$````````````````````````````"^A(`````````
M````````````````````7Q(````````````````````````````#-Q(`````
M```````````````````````!UA(`````````````````````````````CA(`
M```````````````````````````!XA(````````````````````````````#
M&A(`````````````````````````````FA(`````````````````````````
M```!5Q(````````````````````````````"7Q(`````````````````````
M```````!'1(````````````````````````````";1(`````````````````
M````````````41(````````````````````````````!$1(`````````````
M```````````````"JQ(````````````````````````````!CA(`````````
M```````````````````"EA(`````````````````````````````ZQ(`````
M```````````````````````#,!(````````````````````````````"@A(`
M```````````````````````````#2B$````````````````````````````!
M<!(`````````````````````````````;A(`````````````````````````
M````SQ(````````````````````````````!3A(`````````````````````
M```````#`1(````````````````````````````"-A(`````````````````
M````````````-R`````````````````````````````#2Q$`````````````
M```````````````"S!(````````````````````````````!^Q(`````````
M```````````````````"N1(````````````````````````````"/A(`````
M```````````````````````"#Q(````````````````````````````"Q!(`
M```````````````````````````#CQ(```X```````!E(`````````"F```#
M71(```\```````!F:``````````````#NQ(```X```````!6$`````````L&
M```#1!(```X````````I@`````````*8```#8Q(```X```````!.,```````
M```&```$.A(```X```````!..`````````)0```$-!(```P````````AP```
M```````````$9Q(```X```````!A&`````````0&```$)A```!D```````#"
MD``````````````#HA(```X```````!0B`````````!.```#U1$``!``````
M``!FF``````````$```$%!```!D```````#2P``````````````$,A(```X`
M``````!,J``````````\```$1Q(```X```````!4P`````````%.```$61(`
M``X```````!3V`````````"F```#R!```!@```````#!V``````````````#
MKQ(```X```````!0V`````````$Z```#FQ```!@```````#"D```````````
M```$"A$``!@```````#"B``````````(```#4Q(```X```````!F8```````
M```"```#^A(```X```````!E\`````````!J```#SA(```X````````L&```
M```````````#RB```!@```````#!V``````````````#=!(```X```````!4
M@``````````\```#Y!(```X```````!-2`````````#H```$&1(```X`````
M``!2&`````````&\`&QI8G!E<FPN<V\`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S
M=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR
M7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO
M861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C
M`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!O<&5N-C0`<F5A9`!?
M7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C
M;&]S90!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP
M`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL
M;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<G-T<@!R;61I<@!?
M7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`
M;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE
M;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P
M<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`%]?;&EB8U]S=&%R=%]M86EN`%]?
M96YV:7)O;@!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`<&%R
M7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A
M<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB
M8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!P87)?:6YI=%]E;G8`7U]B<W-?
M<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR
M`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N-``O=7-R+VQI8B]P
M97)L-2\U+C(V+C$O<S,Y,'@M;&EN=7@M=&AR96%D+6UU;'1I+T-/4D4`````
M`````@`"``,````"``(``@`"``(``@`"```````"```````$``(````"````
M```````````"``4``P````(``@`"````!@````(````"`````@`#`````P`$
M```````"`````@``````!@````0````"``(``@````````````(``@````(`
M`@`#``(``@`#``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!`````0`!```!Q@```!`````@#6EI$@````,`
M``1]```````!``0```(5````$``````):1ET````!@``!(<````0"6D9<@``
M``4```23````$`UI:10````$```$GP```!`-:6D2`````@``!'T`````````
M````O4@`````````#````````"T8````````O5``````````#````````"S(
M````````O\@`````````#````````,'@````````O^``````````#```````
M`"F`````````P>``````````#````````,'@````````P>@`````````#```
M`````&@"````````P?``````````#````````&?J````````P?@`````````
M#````````&?R````````P@``````````#````````&@8````````P@@`````
M````#````````&@`````````PA``````````#````````&@2````````PB``
M````````#````````&D(````````PB@`````````#````````&:<````````
MPC@`````````#````````&>N````````PD``````````#````````&>R````
M````PD@`````````#````````&D.````````PE``````````#````````&;^
M````````PE@`````````#````````&D6````````PF@`````````#```````
M`&D:````````PG``````````#````````&D@````````PH@`````````#```
M`````&G"````````OY`````#````"@``````````````````OY@````%````
M"@``````````````````OZ`````(````"@``````````````````OZ@````.
M````"@``````````````````O[`````4````"@``````````````````O[@`
M```7````"@``````````````````O\`````D````"@``````````````````
MO]`````F````"@``````````````````O]@````Q````"@``````````````
M````O^@````]````"@``````````````````O_````!"````"@``````````
M````````O_@```!#````"@``````````````````P``````"````"P``````
M````````````P`@````#````"P``````````````````P!`````$````"P``
M````````````````P!@````'````"P``````````````````P"`````)````
M"P``````````````````P"@````*````"P``````````````````P#`````+
M````"P``````````````````P#@````,````"P``````````````````P$``
M```-````"P``````````````````P$@````/````"P``````````````````
MP%`````0````"P``````````````````P%@````1````"P``````````````
M````P&`````2````"P``````````````````P&@````3````"P``````````
M````````P'`````5````"P``````````````````P'@````6````"P``````
M````````````P(`````8````"P``````````````````P(@````9````"P``
M````````````````P)`````:````"P``````````````````P)@````;````
M"P``````````````````P*`````<````"P``````````````````P*@````=
M````"P``````````````````P+`````>````"P``````````````````P+@`
M```?````"P``````````````````P,`````@````"P``````````````````
MP,@````A````"P``````````````````P-`````B````"P``````````````
M````P-@````C````"P``````````````````P.`````E````"P``````````
M````````P.@````G````"P``````````````````P/`````H````"P``````
M````````````P/@````I````"P``````````````````P0`````J````"P``
M````````````````P0@````K````"P``````````````````P1`````L````
M"P``````````````````P1@````M````"P``````````````````P2`````N
M````"P``````````````````P2@````O````"P``````````````````P3``
M```P````"P``````````````````P3@````R````"P``````````````````
MP4`````S````"P``````````````````P4@````T````"P``````````````
M````P5`````U````"P``````````````````P5@````V````"P``````````
M````````P6`````W````"P``````````````````P6@````X````"P``````
M````````````P7`````Y````"P``````````````````P7@````Z````"P``
M````````````````P8`````\````"P``````````````````P8@````^````
M"P``````````````````P9`````_````"P``````````````````P9@```!`
M````"P``````````````````P:````!!````"P``````````````````P:@`
M``!$````"P``````````````````P;````!%````"P``````````````````
MP;@```!&````"P``````````````````P<````!'````"P``````````````
M````P<@```!(````"P``````````````````P=````!)````"P``````````
MZV_P,``DN00`'Z?[_V#C$/```"3`P```3M+`$```3O/C$!````2Y`@`1IX0`
M`PWAXT#Q$``$ZV_PT``$!_0'!^,0\#@`),`0``!.N=('\#`0".,0$!``!`?Q
M!P`'``<`P!```$[PXQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```3N3C
M$!````0'\0T0XQ`0#``4P/3____5````&,`0``!.V.,0$```!`?Q#1#C$!`,
M`!3`]/___\4````PP!```$[,XQ`0```$!_$-$.,0$`P`%,#T____M0```$C`
M$```3L#C$!````0'\0T0XQ`0#``4P/3___^E````8,`0``!.M.,0$```!`?Q
M#1#C$!`,`!3`]/___Y4```!XP!```$ZHXQ`0```$!_$-$.,0$`P`%,#T____
MA0```)#`$```3ISC$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!.D.,0
M$```!`?Q#1#C$!`,`!3`]/___V4```#`P!```$Z$XQ`0```$!_$-$.,0$`P`
M%,#T____50```-C`$```3GCC$!````0'\0T0XQ`0#``4P/3___]%````\,`0
M``!.;.,0$```!`?Q#1#C$!`,`!3`]/___S4```$(P!```$Y@XQ`0```$!_$-
M$.,0$`P`%,#T____)0```2#`$```3E3C$!````0'\0T0XQ`0#``4P/3___\5
M```!.,`0``!.2.,0$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```$X\XQ`0
M```$!_$-$.,0$`P`%,#T___^]0```6C`$```3C#C$!````0'\0T0XQ`0#``4
MP/3___[E```!@,`0``!.).,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!``
M`$X8XQ`0```$!_$-$.,0$`P`%,#T___^Q0```;#`$```3@SC$!````0'\0T0
MXQ`0#``4P/3___ZU```!R,`0``!.`.,0$```!`?Q#1#C$!`,`!3`]/___J4`
M``'@P!```$WTXQ`0```$!_$-$.,0$`P`%,#T___^E0```?C`$```3>CC$!``
M``0'\0T0XQ`0#``4P/3___Z%```"$,`0``!-W.,0$```!`?Q#1#C$!`,`!3`
M]/___G4```(HP!```$W0XQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```
M3<3C$!````0'\0T0XQ`0#``4P/3___Y5```"6,`0``!-N.,0$```!`?Q#1#C
M$!`,`!3`]/___D4```)PP!```$VLXQ`0```$!_$-$.,0$`P`%,#T___^-0``
M`HC`$```3:#C$!````0'\0T0XQ`0#``4P/3___XE```"H,`0``!-E.,0$```
M!`?Q#1#C$!`,`!3`]/___A4```*XP!```$V(XQ`0```$!_$-$.,0$`P`%,#T
M___^!0```M#`$```37SC$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!-
M<.,0$```!`?Q#1#C$!`,`!3`]/___>4```,`P!```$UDXQ`0```$!_$-$.,0
M$`P`%,#T___]U0```QC`$```35CC$!````0'\0T0XQ`0#``4P/3___W%```#
M,,`0``!-3.,0$```!`?Q#1#C$!`,`!3`]/___;4```-(P!```$U`XQ`0```$
M!_$-$.,0$`P`%,#T___]I0```V#`$```333C$!````0'\0T0XQ`0#``4P/3_
M__V5```#>,`0``!-*.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```$T<
MXQ`0```$!_$-$.,0$`P`%,#T___]=0```ZC`$```31#C$!````0'\0T0XQ`0
M#``4P/3___UE```#P,`0``!-!.,0$```!`?Q#1#C$!`,`!3`]/___54```/8
MP!```$SXXQ`0```$!_$-$.,0$`P`%,#T___]10```_#`$```3.SC$!````0'
M\0T0XQ`0#``4P/3___TU```$",`0``!,X.,0$```!`?Q#1#C$!`,`!3`]/__
M_24```0@P!```$S4XQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```3,CC
M$!````0'\0T0XQ`0#``4P/3___T%```$4,`0``!,O.,0$```!`?Q#1#C$!`,
M`!3`]/___/4```1HP!```$RPXQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`
M$```3*3C$!````0'\0T0XQ`0#``4P/3___S5```$F,`0``!,F.,0$```!`?Q
M#1#C$!`,`!3`]/___,4```2PP!```$R,XQ`0```$!_$-$.,0$`P`%,#T___\
MM0``!,C`$```3(#C$!````0'\0T0XQ`0#``4P/3___RE```$X,`0``!,=.,0
M$```!`?Q#1#C$!`,`!3`]/___)4```3XP!```$QHXQ`0```$!_$-$.,0$`P`
M%,#T___\A0``!1#`$```3%SC$!````0'\0T0XQ`0#``4P/3___QU```%*,`0
M``!,4.,0$```!`?Q#1#C$!`,`!3`]/___&4```5`P!```$Q$XQ`0```$!_$-
M$.,0$`P`%,#T___\50``!5C`$```3#CC$!````0'\0T0XQ`0#``4P/3___Q%
M```%<.MO\#``),#0```^L>/P_SC_<>,P\*@`).-`\*``)%`@\+2R3P`0ZQ$`
M(``-LD\`$4%`\*!!,/"H02#PM-('\,`0*,#E___^#\1(``!+",0H``!+#;D$
M`#3`Y0``'?C$&```2NV5`!``IX0`QL2X``!*XN,@L```%L#E____=)8")/KC
M(+```!;`Y?___VQ8$/"TE@$D^J<:``5!(-``N10`$>,0(```(:<D`-;K(0`#
M``W`Y?___5?`$```5#CE3!````3C,/"H``3`$```'[CC0#````3C$"`(`"3C
M0"```"3$&```3!/C$"`0`"3$*P``5!G`$```'Z7C$"`8`"180/"TITX``:?$
M`"'L5/_^`-CL51V\`U5!$#`(004P$*=8``7CL!````2Y%``UIUH``>LS``,`
M#>.S+_C_)*<;``BY(``0IW3_[^P4``0`V*=*``.Y%``1ZQ$``P`-XQ$O^/]Q
MN00`4KD4`$3E2!````"G:0``P#```!#YQ"@``%/>P.7___X_&+(2(J>$`%O$
M*```4]1!H/"\P.7___QSN00`.L`@```>$\#E```,R[D"`"*GA``ZQ"@``%/`
MP.7___PAP.7___WNLD\`$+D4`"OK$0`@``VR3P`1U0?PP!`HIW0`4^-`\3@`
M!.MO\/@`!`?TP.7___QVQ"L``%.?N0(`(J>$`$7`Y?__^^S$N```2A'C(+``
M`!;`Y?___J.2`"DAI_3_)\`0``!3A.,@$````J>$`!G`Y0``'+2G]/^]Q"@`
M`%-[P.7___Y,&+*G]/^@Q#@``$G^P"```!Z%P.7___U@N00`.L`@```=B,#E
M```,:,0K``!37;D"`"*GA/^<I_3_VL#E___[S*<I``'`Y?___,=!0/`(XS#P
M```$IPG_\+F``/"G^_]0UP?P`/``Z^_PH``D07#PH,!@```=$<!0```<UL`@
M``!)R^,@(```!,#E___\U0``!P?`$```2QC`(```2Q6Y(``2IX0`"L08``!)
MDKD"`!&GA``#!_$'_@<'P!```$L$P"```$L!N0D`$NL1``,`"NLQ`#\`#+D(
M`#'K,P`!``JY`@`SIX0`"L08``!)G;D"`!&GA``#!_$'_NN_\%@`),"P``!*
MX>/P_V#_<94`L`"G=``5P!```$E7XQ`0```"IX0`",0H``!*=\#E___ZI,#E
M____L9(!L`#C0/$0``3KO_#X``0']`<'P/3___^X!P>R3P`PIUD`".LS`"``
M#>MO\#``)+)/`#'C\/S8_W%!L"`X01#PH+D$`$'2!_,@,"CC,+````3K`P`@
M``SC`$```"3`.@````#C,$`(`"1!L+`(ITL`$*=7_^VG20!`XS`0:``$XS`0
M0`""XS`0$`""XS`0``""[%,@OR%5[%,@/@%6XU`0@``DIQL`"*='_^GCL"`(
M``3CD"`0``3C`"`8``3C$/"@``2YYP!)PAI:@GF9N8``2^,0("``"+F"`$#C
M4"````3LA2"_)57LA2`Z!5:Y"`"!ZQL``@`,N0@`A.P;`"$>5N-`\*@`!.QQ
M(+\`5<)*6H)YF;GG<#FY@``UN8(`.<"*`````+GH`&3KV``;``RY"`!C[-@@
M.@56ZT4``@`,N0@`;>Q%`"$>5L!J`````+F"`!3K-@`;``RY@``8[#8@.@56
MN8(`%[/!`"/CH/"X``3C,/"P``3"JEJ">9G".EJ">9FY"`"GN0@`.;/-`'*Y
M"``QZQ@``@`,[!@`(1Y6N><0A,!*`````+F``(:Y@@"$N0@`-[GHH'CC@/#`
M``3"BEJ">9FYZ$!(P#H`````[($@OP!5L\$`)..@\,@`!.M&``(`#,*J6H)Y
MF>Q&`"$>5KD(`*BY@@`4N8``$[F"`!BSS0""Z],`&P`,N0@`&.S3(#H%5NN#
M``(`#+D(`'WL@P`A'E;`>@````"Y!``XN>>`A,!*`````+F``(>Y@@"$N>B@
M:..`\-``!,**6H)YF;GH0$CL@R"_`%6SP0`DZ]<`&P`,ZT<``@`,[-<@.@56
M[$<`(1Y6N0@`';F"`#3`&@````#CH/#8``2Y@``QPJI:@GF9N8(`.+D(`*BS
MS0""Z]$`&P`,N0@`..S1(#H%5NN!``(`#+D(`&WL@0`A'E;`:@````"Y!``8
MN>>`A,!*`````+F``(:Y@@"$N>B@>..`\.``!,**6H)YF;GH0$CL@2"_`%6S
MP0`DZ]8`&P`,ZT8``@`,[-8@.@56[$8`(1Y6N0@`/;F"`!3`.@````#CH/#H
M``2Y@``3PJI:@GF9N8(`&+D(`*BSS0""Z],`&P`,N0@`&.S3(#H%5NN#``(`
M#+D(`'WL@P`A'E;`>@````"Y!``XN>>`A,!*`````+F``(>Y@@"$N>B@:.O7
M`!L`#..`\/``!,**6H)YF;GH0$CL@R"_`%7LUR`Z!5:SP0`DN0@`'>M'``(`
M#,`:`````.Q'`"$>5N.@\/@`!+F"`#3"JEJ">9FY@``QN0@`J+F"`#BSS0""
MZ]$`&P`,N0@`..S1(#H%5NN!``(`#+D(`&WL@0`A'E;`:@````"YYX!TP$H`
M````N8``=KF"`'2Y!``8N>B@A^-P\0``!,)Z6H)YF;GH0$?L<2"_`%6SP0`D
MZ]8`&P`,ZT8``@`,[-8@.@56[$8`(1Y6N0@`/;F"`!3`.@````#CH/$(``2Y
M@``3PJI:@GF9N8(`%[D(`*>SS0!RZ],`&P`,N0@`%^S3(#H%5NMS``(`#+D(
M`(WL<P`A'E;`B@````"Y!``WN>=P=,!*`````+F``'BY@@!TN>B@9^-P\1``
M!,)Z6H)YF;GH0$?L<R"_`%6SP0`DZT@``@`,[$@`(1Y6N8(`-.O8`!L`#.S8
M(#H%5KD(`!W`&@````"YY!"#L\T`,KF"`(?KT0`;``RY"`"#[-$@.@56ZS$`
M`@`,N0@`;>PQ`"$>5L!J`````..@\1@`!,*J6H)YF;D(`*>YYS!TP$H`````
MN8``=KF"`'2Y!``3N>B@-^-P\2``!,)Z6H)YF>O6`!L`#+GH0$?LUB`Z!5;L
M<2"_`%6Y"`"-L\$`),"*`````.M&``(`#.O8`!L`#.Q&`"$>5NS8(#H%5KF"
M`!3CH/$H``2Y@``8PJI:@GF9N8(`%[D(`*>SS0!R[&0@OP!5N0@`/;D(`!?`
M.@````#K>``"``SKTP`;``SL>``A'E;LTR`Z!5:YYW"$N8``@[F"`(:Y"``=
MN>B@2,`:`````.N#``(`#.O1`!L`#.R#`"$>5NS1(#H%5N.@\3``!,*J6H)Y
MF;D(`*;L9R"_`%6Y@@!XN0@`3;GD$#?`2@````#C</$X``3KU``;``S">EJ"
M>9GLU"`Z!5:Y"`!VN8(`-K/!`">Y"``ZZW$``@`,N0@`/>QQ`"$>5NS8(+\`
M5;GG<&CL@R"_`%6Y@`!DZZ@`&P`,N8(`;>RH(#H%5K/-`!*YZ!`6ZV0``@`,
MN0@`&NQD`"$>5KGG8*>Y@@`ZXT#Q0``$ZZ@``@`,PDINV>NA[*@`(1Y6N0@`
M3;D$`(JY&@!#N>>@IKD$`#2Y@@"A[-$@OP!5ZTT`&P`,[$T@.@56N0@`0^,P
M\4@`!.P4(+\`5<(Z;MGKH;D:`#>Y&@`ZZZ$`&P`,[*$@.@56ZWT``@`,N0@`
M.NQ]`"$>5KGG<*BY@@"DX]#Q4``$[$,@OP!5PMINV>NAN1H`UKD:`-KKI``;
M``SLI"`Z!5;K80`"``RY"`#:[&$`(1Y6N>=@I[F"`*/C$/%8``3L/2"_`%7"
M&F[9ZZ&Y&@`8N1H`&NNC`!L`#.RC(#H%5KD(`!KKA``"``SCH/%@``3"JF[9
MZZ'LA``A'E:SP0`*[$$@OP!5ZZ,``@`,L\$`:K/-`*"Y&@"GZW0`&P`,L\$`
M)[GG@':SP0!'L\T`=NQS`"$>5K/-`#2Y@@#3L\T`,NPT(#H%5K/!`".Y!``Z
MN1H`/;/-`-*YYW"HN0@`/;F"`*'LTR"_`%7C$/%H``3"&F[9ZZ&Y&@`6ZVT`
M&P`,[&T@.@56N1H`&NND``(`#+D(`!;LI``A'E:Y!`!JN>>@I^-`\7``!,)*
M;MGKH;D:`$BYYS"*[#$@OP!5ZZ,`&P`,[*,@.@56N1H`2.N-``(`#+D(`$KL
MC0`A'E;CT/%X``2YYX"FPMINV>NAN8(`H;D$`!WLU""_`%6Y&@`7N1H`&NNM
M`!L`#.RM(#H%5NMS``(`#.QS`"$>5KGHH#&YYW"HN8(`I.,0\8``!.Q#(+\`
M5<(:;MGKH;D:`!:Y&@`:ZZ0`&P`,[*0@.@56ZVT``@`,N0@`&NQM`"$>5N/0
M\8@`!+GG8*?"VF[9ZZ&Y@@"CN00`/>S1(+\`5;D:`#BY&@`ZZZT`&P`,[*T@
M.@56ZX0``@`,[(0`(1Y6N>B@0[GG@*:Y@@"AXS#QD``$[!0@OP!5PCINV>NA
MN1H`-[D:`#KKH0`;``SLH2`Z!5;K?0`"``RY"``Z['T`(1Y6X]#QF``$N>=P
MJ,+:;MGKH;F"`*2Y!`!-[-,@OP!5N1H`1KD:`$KKK0`;``SLK2`Z!5;K80`"
M``SL80`A'E:YZ*`4N>=@I[F"`*/C0/&@``3L,2"_`%7"2F[9ZZ&Y&@!(N1H`
M2NNC`!L`#.RC(#H%5NN-``(`#+D(`$KLC0`A'E;CT/&H``2YYX"FPMINV>NA
MN8(`H;D$`!WLU""_`%6Y&@`7N1H`&NNM`!L`#.RM(#H%5NMS``(`#.QS`"$>
M5KGHH#&YYW"HN8(`I.,0\;``!.Q#(+\`5<(:;MGKH;D:`!:Y&@`:ZZ0`&P`,
M[*0@.@56ZVT``@`,N0@`&NQM`"$>5N/0\;@`!+GG8*?"VF[9ZZ&Y@@"CN00`
M/>S1(+\`5;D:`#BY&@`ZZZT`&P`,[*T@.@56ZX0``@`,[(0`(1Y6N>B@0[GG
M@*:Y@@"AXS#QP``$[!0@OP!5PCINV>NAN1H`-[D:`#KKH0`;``SLH2`Z!5:Y
M"``ZXZ#QR``$PJINV>NAZWT``@`,['T`(1Y6N>=PV+F"`-2Y!`!*N1H`1NQC
M(+\`5;D:`$WKI@`;``SLIB`Z!5;KT0`"``SLT0`A'E:YZ*`4N>?01^.@\=``
M!+F"`$/"JF[9ZZ&Y&@"HN00`BKD:`(3L,2"_`%7K1@`"``SKHP`;``SL1@`A
M'E;LHR`Z!5:YZ*!HN>=`C;F"`!CC@/'8``3"BF[9ZZ&Y&@"'P&H`````N00`
M>.NF`!L`#.RF(#H%5KD$`(JY&@!QXZ#QX``$N0@`>,*JCQN\W.L3``(`#+D:
M`*WL$P`A'E;LU""_`%6YYA"$[$$@OP!5N8``AKGD0#VY@0"#N0@`BL!Z````
M`..@\>@`!.LW`!L`#,*JCQN\W.PW(#H%5KD(`*VY"``XZX8``@`,[(8`(1Y6
M[&@@OP!5N>:`T;GD8!2Y@`#7N8$`T;D(`-K`.@````#CH/'P``3K$P`;``S"
MJH\;O-SL$R`Z!5:Y"`"DN0@`'>M'``(`#.Q'`"$>5NS4(+\`5;F!`(2YY-!V
MN8``@[F!`(>Y"`"*P!H`````ZW$`&P`,['$@.@56N0@`>.N#``(`#.R#`"$>
M5N.@\?@`!+F!`$C"JH\;O-RY@`!!N0@`IKD$`#CL:""_`%6YY&"-N8$`2+D(
M`$K`>@````#KAP`;``SLAR`Z!5:Y"`"$ZT$``@`,[$$`(1Y6XZ#R```$N8$`
M-,*JCQN\W+F``#>Y"`"MN00`%.S4(+\`5;GDT$:Y@0`TN0@`.L"*`````.M(
M`!L`#.Q((#H%5KD(`$/K-P`"``SL-P`A'E;CH/((``2Y@0`3PJJ/&[S<N8``
M&+D(`*:Y!`!S[&,@OP!5N>1@/;F!`!.Y"``:P$H`````ZS0`&P`,[#0@.@56
MN0@`,>L8``(`#.P8`"$>5N.@\A``!+D$`(&Y@0!QPJJ/&[S<N8``=+D(`*WL
MT2"_`%6YY-`6N8$`<;D(`'K`.@````#CH/(8``3K$P`;``S"JH\;O-SL$R`Z
M!5:Y"`"FN0@`%^MT``(`#.QT`"$>5KD$`$>YYG!X[&0@OP!5N8``<[GD8(VY
M@0!XN0@`>L`:`````.N!`!L`#.R!(#H%5KD(`(?K<P`"``SL<P`A'E:YYG`T
MN8``,>.@\B``!,*JCQN\W+D(`*WLUR"_`%6SP0`JN>301KF!`$.SS0`RP(H`
M````N0@`0^NH`!L`#+D$`#KL."`Z!5;KH0`"``RY"`!#N00`.L!*`````.PQ
M`"$>5KGF,!?L<R"_`%6Y@``8N>1PK;F!`!JSP0!!ZZ@``@`,ZQ0`&P`,L\$`
M`>RH`"$>5N,0\B@`!,(:CQN\W+/!`"&SS0`0[!0@.@56L\$``;/-`!*Y"`!A
MN00`BK/-`!2Y"``6L\T`8..@\C``!+D(`!;"JH\;O-SL:""_`%6Y"`"MN>:`
MT[GD8#?`&@````"Y@`#4N8$`T^LQ`!L`#+D(`-KL,2`Z!5:Y"``]XZ#R.``$
MPJJ/&[S<N0@`I^QS(+\`5>LT``(`#.PT`"$>5NS3(+\`5;GF,$BYY-"&N8``
M0;F!`$BY"`!*ZX<`&P`,[(<@.@56N0@`A.M!``(`#.Q!`"$>5N.@\D``!+F!
M`#3"JH\;O-RY@``WN0@`IKD$`!3L9""_`%6YY&!-N8$`-+D(`#K`B@````#C
MH/)(``3K2``;``S"JH\;O-SL2"`Z!5:Y"`"MN0@`0^LW``(`#.PW`"$>5NS3
M(+\`5;F!`!.YY-!VN8``&+F!`!>Y"``:P$H`````XZ#R4``$ZW0`&P`,PJJ/
M&[S<['0@.@56N0@`IKD(`''K&``"``SL&``A'E;L82"_`%6Y@0`QN>1@C;F`
M`#2Y@0`XN0@`.L!Z`````..@\E@`!.N'`!L`#,*JCQN\W.R'(#H%5KD(`*VY
M"`"#ZS0``@`,[#0`(1Y6[-,@OP!5N8$`$[GDT$:Y@``7N8$`%+D(`!K`B@``
M``#CH/)@``3K2``;``S"JH\;O-SL2"`Z!5:Y"`"FN0@`0>L7``(`#.P7`"$>
M5NQQ(+\`5;F!`#&YY'!MN8``.+F!`#:Y"``ZP$H`````XZ#R:``$ZV0`&P`,
MPJJ/&[S<[&0@.@56N0@`K;D(`&/K.``"``SL.``A'E:Y!`"#N>8P,>S8(+\`
M5;GDT!?`:@````"Y@``TN8$`,>L6`!L`#+D(`#KL%B`Z!5:Y"``3XZ#R<``$
MZS0``@`,PJJ/&[S<[#0`(1Y6N0@`I^QQ(+\`5;GF,!CL@R"_`%6Y@``6N>2`
M3;F!`!2Y"``:ZT<`&P`,XZ#R>``$[$<@.@56PJJ/&[S<N0@`0;D(`*WK%@`"
M``SL%@`A'E:Y!`!AN>80$^S6(+\`5;GDT#BY@``7N8$`$^PT(+\`5;D(`!KK
MHP`;``SLHR`Z!5:Y"``:ZZ<``@`,[*<`(1Y6N00`>N.@\H``!+F"`&?"JLIB
MP=:Y"`"HN>=`AKD:`*CL02"_`%6Y!`"*ZZ0`&P`,[*0@.@56ZV,``@`,[&,`
M(1Y6N>B@...@\H@`!,*JRF+!UKGG8(>Y@@"!N>C0&NS3(+\`5>NM`!L`#.RM
M(#H%5KD:`!CKA``"``RY"``:[(0`(1Y6N>>`IKF"`*/C0/*0``3L,2"_`%7"
M2LIBP=:Y&@!'N1H`2NNC`!L`#.RC(#H%5NM]``(`#+D(`$KL?0`A'E;CT/*8
M``2YYW"HPMK*8L'6N8(`H;D$`!WLU""_`%6Y&@`6N1H`&NNM`!L`#.RM(#H%
M5NMC``(`#.QC`"$>5KGHH#&YYV"GN8(`I.,0\J``!.Q#(+\`5<(:RF+!UKD:
M`!BY&@`:ZZ0`&P`,[*0@.@56ZXT``@`,N0@`&NR-`"$>5N/0\J@`!+GG@*;"
MVLIBP=:Y@@"CN00`/>S1(+\`5;D:`#>Y&@`ZZZT`&P`,[*T@.@56ZW0``@`,
M['0`(1Y6N>B@0[GG<*BY@@"AXS#RL``$[!0@OP!5PCK*8L'6N1H`-KD:`#KK
MH0`;``SLH2`Z!5;K;0`"``RY"``Z[&T`(1Y6X]#RN``$N>=@I\+:RF+!UKF"
M`*2Y!`!-[-,@OP!5N1H`2+D:`$KKK0`;``SLK2`Z!5;K@0`"``SL@0`A'E:Y
MZ*`4N>>`IKF"`*/C0/+```3L,2"_`%7"2LIBP=:Y&@!'N1H`2NNC`!L`#.RC
M(#H%5NM]``(`#+D(`$KL?0`A'E;CT/+(``2YYW"HPMK*8L'6N8(`H;D$`!WL
MU""_`%6Y&@`6N1H`&NNM`!L`#.RM(#H%5NMC``(`#.QC`"$>5KGHH#&YYV"G
MN8(`I.,0\M``!.Q#(+\`5<(:RF+!UKD:`!BY&@`:ZZ0`&P`,[*0@.@56ZXT`
M`@`,N0@`&NR-`"$>5N/0\M@`!+GG@*;"VLIBP=:Y@@"CN00`/>S1(+\`5;D:
M`#>Y&@`ZZZT`&P`,[*T@.@56ZW0``@`,['0`(1Y6N>B@0[GG<*BY@@`:XS#R
MX``$ZZT``@`,PCK*8L'6[*T`(1Y6N1H`-KD$`-KL9""_`%6YYZ"GN1H`,;F"
M`$JY!``3XZ#R\``$ZS8`&P`,PJK*8L'6[#8@.@56N1H`I[D(`#'C$/+H``3"
M&LIBP=:Y&@`8[(,@OP!5N1H`%.M(`!L`#.Q((#H%5KD(`!3L<2"_`%7K1@`"
M``SL1@`A'E:YYT!MN8(`8^LX``(`#+D:`*;L.``A'E:YYS"$N8(`&.-@\O@`
M!.N'`!L`#,)JRF+!UNR'(#H%5KD:`&VY"`"*N1H`8>L7``(`#+D$`-;L%P`A
M'E:YYQ"CN8(`J.QX(+\`5>.`\P``!.MG`!L`#,**RF+!UNQG(#H%5KD:`(2Y
M"`!MN1H`BNS6(+\`5>NM`!L`#.RM(#H%5NM'``(`#.Q'`"$>5KGHH'BYYT"A
MN8(`IN.`\P@`!.QG(+\`5<**RF+!UKD:`(.Y&@"*ZZ8`&P`,[*8@.@56ZST`
M`@`,N0@`BNP]`"$>5N.@("``!+GG,-2Y&@"CN8(`?<"J`````..@("``)./0
M\Q``!.RH(+\`5<+:RF+!UKD:`-'K&@`;``RY&@#7[!H@.@56ZW8``@`,N0@`
M'>QV`"$>5L`:`````+GG<&.Y&@`'N>@0.\`*`````,`Z`````.,`(!@`).,P
M(`@`)+F"`(;K`0`;``SCL/,8``3L`2`Z!5;"NLIBP=;K&@`"``RY!``[[!H@
M(1Y6N1H`-+D(`)&Y&@`XP)H`````XY`@$``DN0@`,+D:`%/`6@````#C4"``
M`"2R3P`0ZQ$`(``-LD\`$=4'\R`0**=T``GC0/.8``3K;_-8``0'],#E___O
M=0<'!P?K;_`P`"3C\/]@_W&Y`@""IX0`9L08```]DN-P$````J>$`%[C$(``
M`)02$:>$``:G'@`]IW0`,:>8``#CH'````*GA``AN00`8[D4`)FY!`"WN00`
M2;D$`#BY!``JP.7___'!$B*G=``(01F@`)4]$`"GA``C0;"P"..@L````J=T
M_^FY!``JXT#Q$``$ZV_PT``$!_2Y!`"809"0`>,0D```E!(1IX0`!J<>`#VG
M=/_V&YBG]/_$N0D`MT&IH`'KNP`#``JY!``J4+!@`.-`\1``!.MO\-``!`?T
MIZD``*?T_]('!P<'ZZ_P4``DLD\`$./P_U#_<>L1`"``#;D$`**R3P`10;#P
MI-('\*@0*+D$`#NY!``JP.7___]TN0(`(J>$`"_$*```/0GC$/"D`!3K$0`#
M``WC$"````CC(!`(``3C(!```"2Y`@`BIX3_X4$0$`CC(!`(``3C(!```"2Y
M`@`BIW3_]KD$`#NY!``JP.7___]'N0(`(J=T_]6R3P`0ZQ$`(``-LD\`$=4'
M\*@0**=T``GC0/$@``3KK_$```0'],#E___NG0<'!P?K;_`P`"2R3P`0X_#_
M2/]QZQ$`(``-LD\`$;D$`+*Y!`"CT@?PL!`HE3TP`*=T``1!H#`!IP@``+D$
M`!JGF0``LEX`D:<4__ZY"0":03#PK+D$`"O`Y?___OZY`@`BIX0`N*<(``"G
M&0``N00`,K)>`!.G%/_^N0D`$KDA`!FGI`",X]#PK``4Q(@``#R`Z]T``P`-
MXQ"P``"4$A&GA`$/IQX`/:>$`0NY!``;I_0`!J<N`#VGA``*01`0`>,@$```
ME!(BIW3_]KD)`!NY%``1N00`?4$I$`+C<(````C`Y?__[OGC('```"2Y`@`B
MIX0`\.,0L```D.-`@```!.,P\*P`%.LS``,`#>,S0```!$(0,`!!L+`!P!L`
M``#_IW0`$J?T`!3C$+```)!"$#`!0;"P`4$P,`'`&P```/^GA``&IQX`/:=T
M__"2/3``IQD``.,AH```D$(A,`&G&P`!N0(`(J=T__>G*```LD\`$+D4`"+K
M$0`@``VR3P`1U0?PL!`HIW0`J>-0\2@`!.MO\.@`!`?UXQ"@``"00A`@`$&@
MH`%!("`!N0(`$:>$_][C$*```)!"$"``0:"@`4$@(`&Y`@`1IW3_Z*?T_\_$
MB```.]WC8(````3C$&````*GA`!QN00`%J<H``"G]``#&"?L<@`!`-A!$!`(
MXS`0```"IW3_]Z<J``.Y%``BZR(``P`-P!```$4*XQ`0```2IW0`-<`0``!%
M`N5,$````<#E___N4+D"`!+C$/"@`"2GA`!'N00`-KD4`&?KU@`#``VY!`!-
MP.7__^SMXQ#PH``$XQ"````DIVL``>,0\*``!.MF``,`#4$6$`#E2!````!0
M</"LI_3_![D$`#*Y!``FP.7__^UOXR#PH``DXR"````DN0(`(J>$`!.Y%`!G
MZ]8``P`-I_3_V:<9``"G]/\)IRD`$*=X``"G]/^EIRC__Z?T_TW`Y?__[2T'
M!P<'ZV_P,``DLD\`$./P_L#_<>L1`"``#;)/`!&Y`@"BT@?Q.!`HIX0`!I4`
MH`"G=``5LD\`$.L1`"``#;)/`!'5!_$X$"BG=`"5XT#QL``$ZV_Q<``$!_3`
MY?__[]VY`@"2IX3_Z$%P\*BY!``IP.7__^]BN0(`(J>$`&M!L"`3P!````YG
MIP@``+D$`"NR70`2IQ3__J>$_^K`$```#ENY!``KLET`$J<4__ZGA/_?N00`
M&J<I``"Y!``[LEX`(:<4__ZG&0``N0D`*KD$`&JR7@`3IQ3__KD)`!L:(:<J
M``*Y%``BP.7__^V&X[#PH``DN00`@L!0```.+Z=)__^G.0`!P.7__^X7N00`
M1[D$`#BG*0`!P.7__^\NIR[__[D$`"BGA``+6!#PP,`;``#P`*<>0`"GA``8
MP.7__^U,N00`*,#E___L%Z?T_Y"Y!``IP.7__^]`N00`*L#E___L2Z?T_VC`
MY?___TZG]/_JP.7__^QQ!P<'!^NO\%``)./P_V#_<;D$`*+$N```.FSC(+``
M`!;`Y?__[O[L0@(``-FY!``ZIRD``<#E___O!!(BIX0`#:<H``#C0/$0``2Y
M%``BZZ_P\``$!_3C(+```!;`Y?__[N!8$"(8P!L``/``IQY``*>$`!+C(+``
M`!;`Y?__[M%8$"(8P!L``/``PAT``*``IW3_V+D$`"JG.0`"P.7__^Y`XT#Q
M$``$$"*G*O__ZZ_P\``$B"``'[D4`"(']`<'!P<'![)/`!#K$0`@``VR3P`1
MZW_P.``DX_#_6/YQXU#PH`%QN00`DKD$`'-!L/"@ITD/_[D$`#O`(```#7;2
M!U``$"C`Y?__[%P2(J?$`%;L$O__`-C$.```.>NY%`"A6(`P`$$Z\*"5`#``
MIX0`-;D4`**Y!`!*ISD`+[D$`"O`Y?__[7ZY`@`BIX0`*;D6`"C`Y?__[F6Y
M!`!:N00`2[D$`#G`Y?__[@RR3P`0XR#PH`%QZQ$`(``-LD\`$=4'(``0**=T
M`"WC0/$8`03K?_#@`00']!(1IW3_SKD6`"C`Y?__[CZY!`!'N00`.<#E___K
MUZ?T_]O$&```.9I8@!``N18`*,#E___N*[D$`$>Y!``YP.7__^O$I_3_R,#E
M___K?^OO\'``),08```Y@>/P_V#_<>,@$```%L#E___N$,!0```M%<1(```Y
M;L`P```,\^OO\1``!,#T___L\0<'!P?K;_`P`"3C\/]8_W'$N```.5[C(+``
M`!;`8```#ES`Y?__[>W`Y?___\[C(+```!;`Y?__[>2Y!`!6Y4CPH```P$``
M``GXP#````S3P.7__^U&XT#Q&``$ZV_PV``$!_3K;_`P`"2R3P`0X_#_2/UQ
MZQ$`(``-XR#PL`)QLD\`$=('(``0*$&P\*[CH/"O`7'`Y?__Z\3`$```#+SC
M$/"@`"2Y!`!BP%````RNITD0`:<Y``&Y!``KP.7__^QPN00`*Z=)$`"Y!``Z
MP.7__^MG$B*G1``TN00`LJ<J``&Y%``BP.7__^N[N0(`DJ>$``^Y%`"[N00`
M.KD$`$O`Y?__ZHY!&Y``D@`0`+)/`!#C,/"P`G'K$0`@``VY!``ILD\`$=4'
M,``0**=T``WC0/$H`@3K;_#H`@0']*>9``"G]/_FP.7__^J[P/3___^,!P?K
M;_`P`"2R3P`0X_#_0/YQZQ$`(``-XT#PN`%QLD\`$;D$`+*Y!`"3P"````Q-
M03#PM-('0``0*,#E___[**<Y`"^Y!`"BN00`*\#E___KG[D"`"*GA``BN00`
M.\`@```,.,#E___[Z[D$`"NR3P`0XS#PN`%QZQ$`(``-LD\`$=4',``0**=T
M`.+C0/$P`03K;_#P`00']*<(``"Y!``IN00`&Z>9``#`,```#!FR7@"1IQ3_
M_AN;P.7__^R(N0(`(J>$_\NGF@`!P-````O-08#PN)4`(`"GA`")N0(`JJ>$
M``ZG"```N00`$KD$`#JR70`3IQ3__J>$`&FY!``2IP@``*<Y``"R7@`QIQ3_
M_KD)`#(8$[D4`#/C,R___W&5+S``IW0`$:<:__^Y%``Q04,@`)(`0`#C,R__
M_W&5+S``IX3_\QH9IQX/_Z<D_X;CL/"H`"3`$```"\/C$/"@`"3`4```#$JG
M21``ISD``;D$`&*Y!``HP.7__^MHQ'@``#?]XR!P```6P.7__^R/[$("``#9
MN00`.*<I``'`Y?__['42(J=T`!+C('```!;`Y?__['Q8$"(8P!L``/``PAT`
M`(``IX0`*<`P```+B*<I``#`Y?__Z_JY`@`BIX3_/94`(`"G=/][N0(`JJ>$
M``ZG"```N00`';D$`"JR70`2IQ3__J>$_^+`(```"RVG&``!I_3_F:<Y``&Y
M!``HP.7__^O$$B*G=/_1N00`.,`@```+3L#E___[`;D$`"C`Y?__Z32G]/\3
MP.7__^F/N00`$N,@(```D+D"`"*GA``=L\$`#QA"X_#_6/]QN00`(4)`\*>5
M+_"G01`0`>,P$```D+GB@"$80[D"`#.G=/_RL\T`\`?^N00`(0?^!P>Y`@`R
MIX0`+N,@,```E!(BIX0`**<(``"G&0``N00`0[)>`!2G%/_^XQ`?__]QN2$`
M,:>D`#.5+Q``IW0`';GI,$'C$!___W&G1P`2IRX`+Z>$``C`(```"O3`]/__
MZ-?`(```"K+`]/__Z-&5+Q``IX3_Z;GI,$'C4!___W&Y(0`UIR0`6*<___^G
MA`!4XQ`?__]QIT<`/+D@`#&GA/_8N>DP0>,@'___<;DA`#*G)``^IS___Z>$
M`#KC$!___W&G1P`LN0D`$^PA``(`V<(N```0`*<D`"A!0!`!IUD0`,`@```X
M<.OO\'``)./P_V#_<<#E___JR\`@```X9.-`\1``!.OO\1``!`?TE2\0`*=T
M_[^G]/_&E2\0`*>$_\^G]/_2IRD```?^ITD``:?T_\:G20`!I_3_K`<'!P<'
M![)/`!#K$0`@``VR3P`1Z[_P6``DX_#_,/]QP"````IR0;#PH-('\,@0*,`0
M```J/](A\*80`,#E___YK<`@```*9L#E___YI\`@```*9,#E___YH<`@```*
M8\#E___YF\`@```*8<#E___YE<`@```*8\#E___YC\`@```*-<#E___YB<`@
M```*7<#E___Y@\`@```*7,#E___Y?<`@```*6\#E___Y=\`@```*(L#E___Y
M<<`@```*5,#E___Y:\`@```*4\#E___Y9;D$`#O`(```"E'`Y?__^.FY`@`R
MIX0`",`@```*,L#E___YM[D$`#O`(```"DC`Y?__^->Y`@`RIX0`",`@```*
M1\#E___YI;D$`#O`(```"D7`Y?__^,6Y`@`RIX0`),`@```)V\#E___YD\`P
M```*3,`@```)\L#E___YBK)/`!#K$0`@``VR3P`1U0?PR!`HIW0`+.-`\4``
M!.N_\2@`!`?TN00`.\`@```*'\#E___XE[D"`#*G=``1ITD`"L`P```*'$$@
M\+?`Y?__ZGD2(J=T_\U!,/#!P"````G,P.7___E6I_3_P\#E___GZ0<'!P>R
M3P`0ZQ$`(``-LD\`$>OO\'``)./P_U#_<<0M```W1Z<N___2!_"H$"BGA``7
MLD\`$+D4`"+K$0`@``VR3P`1U0?PJ!`HIW0`+>-`\2``!.OO\2``!`?T03#P
MI,`@```)D<#E___X0[D"`"*GA``6XQ`@``"0N0(`$:>$``_`%P```#"Y`P`A
M["(_OP%5Q"\``#<-I_3_S:<H``"G]/_YP.7__^>4!P?K[_!P`"3C\/]@_W'`
MY?__YYK`Y?__YO>Y`@`BIX0`#.,@(```!.-`\1``!.OO\1``!`?TIRD``*?T
M__<'!P<'ZV_P,``DN00`[^/P_P#_<:?K__A@@.``LD\`$.L1`"``#;)/`!'2
M!_#P$"C`$```-G[2-_"X$`#CH/"X``*GA``ZN00`@D&P\,!!</"TP-````D"
MI_0`$KD$`#C`Y?__YH*Y`@`BIX0`.Z>[``CCH+_X_P*GA``?N00`-[D$`"K`
MY?__]\"Y`@"2IX0`!I4`D`"G=/_CN00`*KD$`#C`Y?__^(FGNP`(XZ"_^/\"
MIW3_Y;)/`!#K$0`@``VR3P`1U0?P\!`HIW0`06B`\/CC0/%P``3K;_$P``0'
M]*<(``"Y!``8N00`.;)>`"&G%/_^IQD``+D)`"BY!`!HLEX`$Z<4__ZY"0`9
M02(0`L#E___GNN.0\*@`)./0\*``)+/!`(+`4```"2:G2?__ISD``<#E___H
M2+/-`#BY!``JP.7___@YI_3_D\#E___FS`<'ZV_P,``DN00`[^/P_>CW<:?K
M_]A@@.``8*#@"&#`X!!@X.`88)#@(.,P\>@(<;)/`!#K$0`@``VR3P`107#P
MQ+D$`)+2!S``$"C`,```->/`$```->S`(```"$K2%_#(,`#2+_#X$`#`$```
M-?BY!``WTA?PX!``P.7___<<N0(`LJ>$``:5`+``IW0"1<#E___^\;D"`+*G
MA`)*N00`&Z<(``"G*0``LEX`(:<4__ZY"0`KZR(``0`-IRL``<#E___G.>,0
ML```D+D$`*(88;D"`!&GA``>N00`BKF$`&:Y!``HP%````B9ITG__Z<Y``'`
MY?__Y[_C$+`!`)!!L+`!08"``AAAN0(`$:=T_^CC(/#X``*GA`#-0;#Q`*?T
M``FGNP`(XR"_^/\"IX0`PKD$`#?`Y?__]KZY`@""IX3_\I4`@`"GA/_NP.7_
M__FW$B*GA/_HN00`*,#E___EN[D"`"*GA`"FIP@``+D$`!*GN0``LEX`L:<4
M__ZY!``ZIQD``+D)`+*R7@`3IQ3__KD)`!JY!`!B&K&GN@0$N10`N[D$`"O`
M@```!Z_`Y?__YL+`$```"#KCH/"P`"3C$/"H`"3C@/"@`"2SP0""P%````@G
MITG__Z<Y``'`Y?__YTJSS0`HISD!P,#E___G<Z<N__^G=``+P.7__^<L6!`@
M`*<>`!&G=`'*Q&@``#/+XR!@```6P.7__^A=[$("``#9L\T`.*<I``'`Y?__
MZ&,8HA(BIX0`;\08```SK+/-`&CC4)````3`0```"!#C(!````2G.0`!I[D`
M`,#E___GFK)/`!#C,/'H"''K$0`@``VY!``KLD\`$=4',``0**=T!#KM@/'P
M"&7MH/'X"&7MP/(`"&7MX/(("&7MD/(0"&7C0/*("`3K;_)("`0']*>(``"Y
M%``8ZQ$``P`-X['PR``"IX0`(Y4`L`"GA``?IXH``;D$`"O`Y?__^/`2(J>$
M_^JY!``KP.7__^3TN0(`(J=T_SNY%``8ZQ$``P`-X['PR``"IW3_X:<I``"G
M]/\MXR!@```6P.7__^?<6!`B&,`;``#P`*<>0`"G=/^&XR!@```6P.7__^?-
M6-`B',#E___E.!G2IW3_>.,@8```%L#E___GOU@0(AC`&P```?^G'@'`IW3_
M:;D$`"O`Y?__Y>&Y!``WN00`LL`@```'1L#E___UE[D"`"*GA`$CXW"0```$
MP.7__^2=N00`,KD$`"?`Y?__^D*Y`@!RIX0!$J<(``"G&0``N00`)[)>`!*G
M%/_^N0D`%Z<>``.GQ``?N10`(<`P```'<^,B?_S_<;)=`#*G%/_^IW0`$:<>
M``2GA`+RIQK__+D4`!'C$7___W&5+Q``IX0"Y\#E___\WA(BIW0`#[D$`">G
M.0``P.7__^7XN00`DAAR$B*G=`#7P#````;3P"````:'P.7___81P)````>R
ML\T`:,#E___E4<!0```'0N,@\*@`)..`\*``)..0\+``)*=)__^G.0`!N00`
M*\#E___E_*?T`"S`Y?__Y>=8$"``IQX`$:=T`"ZGJ@`!L\T`:,#E___E*KD4
M`!KC(/"H`"3CD/"X`"3C@/"@`"3C$/"P`"3`4```!Q2G2?__ISD``;D$`"O`
MY?__Y="G.0'`N00`*\#E___E^:<N__^GA/_-L\T`*,#E___CX+D$`#O`(```
M!?C`Y?__];"Y!``KP.7___S3I_3^J<#E___\SKD$`"O`Y?__X]FY!`"RI_3^
MG:>H``"Y%``:ZQ$``P`-XR'PX``"IX0`'Z>J``'C(?#@``2Y!``WP.7___2O
MN0(`$J>$_^J5`!``IX3_YL#E___CM+D"`"*GA/_?N00`LJ?T_9&G*0`-P+``
M``9&P.7__^34IV@`4[D$`**G]/VAN10`$>,0\*``)+/-`&C$&```,?3C4)``
M``3`0```!CSC(!````2G.0`!I[D``,#E___EY*?T_DKC<)````2G]/[MITD`
M`J<Y_^[`Y?__Y&9!$/'HITD`!K/!`,&Y!``QN00`*<#E___C*94`\>BG=``&
ME4/QZ:>$`C6Y%``7N00`*;/!`)&G20``ISD``,#E___D1,`19T4C`>,0\2@`
M)$%@\2C`'^_-JXGC$/$P`"3E2/%0``#`'YBZW/[C$/$X`"3E2/%8``#`$1`R
M5';C$/%``"3E3/&@``#`'\/2X?"GV`!`XQ#Q2``DL\$`JT$0\6"SP0#AI4^`
M`+/-`#RSS0`IP.7__^+:N00`DAAR$B*GQ`"+XS#Q4``$N10`*>L2``,`#;D(
M`!/C0/%8``3`&@````"Y(0`QI\0`!*=+``'C$/%0`"3K(@`=``RYZ$`2XQ#Q
M6``DXQ#QH``2IX0!9KGY$'T9E[/-`#RY\L!YL\T`+KD4`*>Y&``AN00`2L#E
M___B[!@76A#QH%`0\:"G'@!`IW3_LK/-`!RY^7!YN0@`H;D$`";`Y?__Y^BG
M?@`_I\0`'^P7_\``V.NQ``8`WNR;)K\`5:>;``'2/_%@H`"Y!``F0:"@0,#E
M___GSZ>7__:G>O_`ZQL`!@#?&W&Y%`!'N00`.J=9`$BSS0`NP.7__^/LI4^`
M`%!P\:"SS0`\L\T`*<#E___B4;D$`)(8<A(BIR3_>;/-`"FSS0"ZP.7__^6T
MXZ#Q4``$XY#Q6``$["HZOSU5N10`$D$1\6"2@!``IRH``:<N`#BG)`$5L\T`
M'J<X`#BY&``2N?D@(Q(BIX0`&:<J___K,@`(`-X2,Z>$``SC(!0``#;7_Q``
M$`!!$!$`IS;_^+D6`"+&(````6)"D/&;0J#QG^L9`!@`#$(0\9CK&0`0``Q"
M$/&9ZSH`&``,0C#QG.L:`!``#$(0\9VY!``FZYD`"``,0I#QFNNJ``@`#$*@
M\9Y!D/&_07#QK,#E___G0N,0\2@`!$(0\:[K(0`0``Q"(/&LZR$`"``,0B#Q
MK>MA`!@`#.,0\3``!$(0\;+K(0`8``Q"(/&O0F#QJ^LA`!``#$(@\;#K$0`(
M``Q"$/&QXQ#Q.``$0A#QMNLA`!@`#$(@\;.GJ0`4ZR$`$``,0B#QM.L1``@`
M#$(0\;7C$/%```1"$/&ZZR$`&``,0B#QM^LA`!``#.L1``@`#$(@\;A"$/&Y
MXQ#Q2``$ZR$`&``,0A#QOD(@\;OK(0`0``SK$0`(``Q"(/&\0A#QO;D$`"FY
MA`!FP%````18ITG__Z<Y``&GFP`"P.7__^-\IZ<`)D$0\;_C$/"H`"22`/'G
MP!````4,XX#PH``DL\T`:.,0\+``),!0```$D:=)__^G.0`!N00`*\#E___C
M7*?T_9>SS0"LI_3^P$-@<`"G>P`!I_3_QN,0D`@``J>$_1BG"```IRD``+D$
M`#&R7@`CIQ3__KD)`"'"+@````.GQ/T'XS(?_/]QP"````1=LET`(Z<4__ZY
MXH!QI_3\^;/-`#ZG&`!`N1@`,KGY("$2(J>$`!NG*O__N00`$^LR``@`WA(S
MIX0`#.,@%```-M?_$``0`$$0$0"G-O_XN18`(L8@````4+D$`";`Y?__YE/7
M-_%@\6"G]/[CE4'QZJ=T_<N50_'KIW3]QY5(\>RG=/W#E47Q[:=T_;^G20`"
MISG_QKD$`"FSS0!HP.7__^(#L\T`/+D$`"FG20`IP.7__^#*P!````1S8,#P
MJ..`\*``),!0```#^^,0\+``)*=)__^G.0`!N00`*\#E___BPZ?T_/[`Y?__
MX4[7`!``$`#7`!``$``'!^MO\#``)+)/`!#K$0`@``VR3P`1X_#_4/]QQ+@`
M`"\_XR"P```6T@?PJ!`H0=#PI,#E___CS+D$`*+C(+```!;`Y?__X\2Y!``]
MT@`@N:"XP"````+IP.7___&IN0(`(J>$``:5,2``IX0!A,#E___X2N,@L```
M%L#E___CJ*=9``NG20`!P#````/&P.7__^'>N0(`(J>$`6GC("`0``18$+``
MXV`@*``$P"```#ASY5P@```!I\0`:J>8``"GJ``!I_0`%^,@(!``!*<(``#$
M/0``.&"R70`GIQ3__J=T`%"GF@`!IZH``1DZI\0`2;D6`"'`Y?__XVJG60``
MN10`2;D$`#;`Y?__XP&Y`@""IX0!-L0X```X.KD4`!KK$0`#``WC((````3C
M<3````18,"`,6!"P`,`[`"`$`*<^!`"GA/_"N18`(<#E___C/^,P@```!*=9
M``*G20``P.7__^#EIP@``%@0L`#$/0``.!*R70`GIQ3__J>$_[3L(___`-@9
M*:>$`,&Y%@`AP.7__^,=IUD``Z=)``'`,````S[`Y?__X5.Y`@"BIX0`'N,@
ML```%L#E___C">,0H!``!,!````#+.,P$```!,#E___@G>,0H!``!.,0$```
M!)%`$`VG=`#MXR"P```6P.7__^+MIUD``Z=)``'`,````Q+`Y?__X2.Y`@"B
MIX0`'[D$`#W`(````>S`Y?__\,>Y`@"2XR"P```6IX0`ML#E___BS>,0H!``
M!+D$`$GC,!````3`Y?__X&+C(+```!;`Y?__XKRY!`"BXR"P```6P.7__^*T
MITD``<`P```"W,#E___A7,!````"X;D$`#*Y!``JP.7__^!"XR"P```6P.7_
M_^*<D@`@N;D$`#W`(````:+`Y?__\(+$*P``-W>Y!`"RN0(`(J>$`$.G.0'`
MN00`*\#E___A@J<N`!&GA``*[!(``0#8PA\````!IR0`A+)/`!#K$0`@``VR
M3P`1U0?PJ!`HIW0`=>-`\2``!.MO\.``!`?TISX``:?$_S^GJ``!N18`(:>J
M``'`Y?__XE:Y!``VP.7__]]Q6!"P`,:M```W,*=$_^^G]/\HQ"@``#<EP.7_
M__C:Q"L``#<GN00`LKD"`"*G=/^RP"````)QP.7__^$36!"P`*?T_P^5`"`!
MIX3^?Z?T_GK$/0``-PI8$+``["/__P#8&2FG=/[^I_3_N\#E___B&<08```V
M]N,@H!``!.,P$```!.,@(```!,#E___S7J?T_TCC(+```!;`Y?__X@+C$*`0
M``3C,!````3`Y?__X2FG]/\&P.7__]]4Q!@``#;1N00`4KD$`$O`(````C;C
M,!````3`Y?__X,0'!^NO\%``)./P_UC_<;D$`*+`Y?__]=3C$"```)"Y`@`1
MIX0`-Q@QN00`LD(P\*>5+_"G02`@`>,0(```D+GB@+(8,;D"`!&G=/_RP.7_
M__<W$B*GA``7N0(`JJ>$`!.5`*``IX0`#[D$`"NG20`$P#````%4P.7__^&&
M$B*GA``-XT#Q&``$ZZ_P^``$!_2Y!`"RI_3_W+D$`"KKK_#X``3`]/__\<@'
M!\`0```M`.,0$````J>$``CC4!````3`]/__WV'$6```+/+`]/__WUOK?_`X
M`"3C\/]@_W&Y!`"2N00`@[D$`'3`L```*Z3`Y?__W=G`$```*YJY"0"QZ[L`
M`P`*N0(`NZ>$`!*Y!`"AXQ"@```$N00`1Z>K``BY!``XN00`*0WAI[?_].-`
M\1``!.M_\-@`!`?T!P<'!P<'!_X'!P<'!P?K;_`P`"2Y!``?I_O_8.,0\```
M),#````L?@<'XT#Q$``$ZV_PT``$!_0'!P```````@`!+@`N+@``)7,O)7,`
M+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5```+W!R;V,O)6DO)7,`97AE`%!!4E]414U0
M``!005)?4%)/1TY!344``#H`+P!015),-4Q)0@``4$523$Q)0@!015),-4]0
M5```4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,``%!!4E]!4D=67S``
M`%!!4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$
M25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``!005)?0TQ%
M04X]```Q`$Q)0E!!5$@`3$E"4D%265]0051(``!$64Q$7TQ)0E)!4EE?4$%4
M2`!32$Q)0E]0051(``!365-414T``"4P,G@``"5S)7,E<R5S``!P87(M```E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*``!P87)L```N<&%R```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S```O=&UP``!414U01$E2`%1-4`!54T52
M``!54T523D%-10``05)'5@``&`!P97)L```P`%!!4CHZ4&%C:V5R.CI615)3
M24].```Q+C`S-@!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``+64``"TM``!E=F%L("=E>&5C("]U<W(O
M8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN
M9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M2
M96UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F
M("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.
M2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*
M(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M
M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`[
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!
M4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]
M+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%2
M1U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6
M>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H
M,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K
M(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D
M;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U
M9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E
M="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J
M/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X
M("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E
M;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N
M86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U
M:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@
M/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E
M;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D
M9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U
M:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I
M.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@
M)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@
M:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L
M;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H
M(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN
M="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@
M*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H
M+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L
M("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M
M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I
M;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]
M"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I
M.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D
M<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T
M96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N
M=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP
M+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE
M(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M
M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E
M("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P
M;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@```````````?_________W!E<FQX<VDN8P``````
M```!&P,[````U````!G__X*````%5/__AB````#P__^=P````3#__YZH```!
M@/__GW````&P__^B4````?#__Z/(```"+/__I(@```)H__^EJ````J3__Z7H
M```"Q/__ID@```,`__^G,````SS__Z<X```#4/__J8@```.,__^IV````ZS_
M_ZL8```#T/__K-@```0`__^M@```!"3__ZW````$2/__KQ````2(__^Z&```
M!-C__[X@```%&/__OL@```68__^^\```!;#__[]@```%Z``````````4````
M``%Z4@`!>`X!&PP/H`$````````\````'/__A2@``!><`%B&#H<-B`R)"XH*
MBPF,"(T'C@:/!48.R`<#%W8*S\[-S,O*R<C'Q@Z@`4(+````````3````%S_
M_YR(````Y`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L`"`H@*S\[-S,O*R<C'
MQ@Z@`4(+`D0*S\[-S,O*R<C'Q@Z@`4(+```````L````K/__G2````#$`$J*
M"HL)C`B-!XX&CP5&#M`"`JP*S\[-S,O*#J`!0@L````\````W/__G;@```+<
M`$J&#H<-B`R)"XH*BPF,"(T'C@:/!48.V`(#`80*S\[-S,O*R<C'Q@Z@`4(+
M````````.````1S__Z!8```!=`!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`#
M`D0*S\[-S,O*R<C'Q@Z@`4(+````.````5C__Z&4````N@!&B@J+"8P(C0>.
M!H\%1@[``@)$"L_.S<S+R@Z@`4(+`E[/SLW,R\H.H`$`````.````93__Z(8
M```!(`!4APV(#(D+B@J+"8P(C0>.!H\%1@[((@*V"L_.S<S+RLG(QPZ@`4(+
M````````'````=#__Z+\````/`!,C@:/!48.P`)DS\X.H`$````X```!\/__
MHQP```!@`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.R`("4L_.S<S+RLG(Q\8.
MH`$````````X```"+/__HT````#H`$J&#H<-B`R)"XH*BPF,"(T'C@:/!48.
MV$("R`K/SLW,R\K)R,?&#J`!0@L````0```":/__H^P````&`````````#@`
M``)\__^CX````E``2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@(@*&"L_.S<S+
MRLG(Q\8.H`%""P```!P```*X__^E]````$X`5@D/$$@.R`)HSPZ@`0``````
M(````MC__Z8D```!.@`"[(X&CP5&#L`"6,_.#J`!````````+````OS__Z=`
M```!O`!4BPF,"(T'C@:/!48.\`(#`50*S\[-S,L.H`%""P``````(````RS_
M_ZC0````I@!4C@:/!48.T`)\"L_.#J`!0@L`````(````U#__ZE4````/`!&
MC@:/!48.P`)F"L_.#J`!0@L`````/````W3__ZEP```!3@!&A@Z'#8@,B0N*
M"HL)C`B-!XX&CP5*#J`#2)@5`L(*S\[-S,O*R<C'QM@.H`%""P```$P```.T
M__^J@```"P8`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@ZXA0)8F!F9&)H7FQ:<
M%0,"A@K/SLW,R\K)R,?&W-O:V=@.H`%""P``````/```!`3__[4X```$!@!4
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`"`P+L"L_.S<S+RLG(Q\8.H`%""P``
M`````#@```1$__^Y`````*8`1HH*BPF,"(T'C@:/!48.R`("@`K/SLW,R\H.
MH`%""U+/SLW,R\H.H`$``````$````2`__]])````I@`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%3`[H`@,!X`K/SLW,R\K)R,?&#J`!0@L`````````````%```
M!,3__[DH````*```````````````-```!-S__[DX````:@!&APV(#(D+B@J+
M"8P(C0>.!H\%1@[``@)<S\[-S,O*R<C'#J`!```````0```%%/__N7`````"
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M&```
M`````"S(``````````$``````````0`````````!`````````<8`````````
M`0````````(5`````````!T````````$J0`````````,````````(<``````
M````#0```````&9H`````````!D```````"]2``````````;``````````@`
M````````&@```````+U0`````````!P`````````"``````````$````````
M`I``````;__^]0````````C(``````````4````````3"``````````&````
M````":@`````````"@````````3=``````````L`````````&``````````5
M`````````````````````P```````+]X``````````(````````%B```````
M```4``````````<`````````%P```````!PX``````````<````````9(```
M```````(`````````Q@`````````"0`````````8`````&____L`````"```
M``````!O___^````````&+``````;____P`````````"`````&____``````
M```7Y@````!O___Y`````````!4`````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````+U8````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````P>``````````````````````````````*8``````````````````
M```````````````````````B+@```````").````````(FX````````BC@``
M`````"*N````````(LX````````B[@```````",.````````(RX````````C
M3@```````"-N````````(XX````````CK@```````"/.````````(^X`````
M```D#@```````"0N````````)$X````````D;@```````"2.````````)*X`
M```````DS@```````"3N````````)0X````````E+@```````"5.````````
M)6X````````EC@```````"6N````````)<X````````E[@```````"8.````
M````)BX````````F3@```````"9N````````)HX````````FK@```````";.
M````````)NX````````G#@```````"<N````````)TX````````G;@``````
M`">.````````)ZX````````GS@```````"?N````````*`X````````H+@``
M`````"A.````````*&X````````HC@```````"BN````````*,X````````H
M[@```````"D.````````*2X````````I3@```````"EN````````````````
M``#!X````````&@"````````9^H```````!G\@```````&@8````````:```
M``````!H$@``````````````````:0@```````!FG```````````````````
M9ZX```````!GL@```````&D.````````9OX```````!I%@``````````````
M````:1H```````!I(```````````_____P````````````!IPD=#0SH@*%-5
M4T4@3&EN=7@I(#<N-2XP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD
M<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`
M+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````````````````````````
M``````````````````````L````!``````````(````````".`````````(X
M``````````\````````````````````!```````````````3````!P``````
M```"`````````D@````````"2``````````D````````````````````!```
M````````````)@````<``````````@````````)L`````````FP`````````
M(`````````````````````0``````````````#@````%``````````(`````
M```"D`````````*0````````!C@````&```````````````(``````````@`
M```T;___]@`````````"````````",@````````(R`````````#<````!@``
M````````````"```````````````/@````L``````````@````````FH````
M````":@````````)8`````<````"``````````@`````````&````$8````#
M``````````(````````3"````````!,(````````!-T`````````````````
M```!``````````````!.;____P`````````"````````%^8````````7Y@``
M``````#(````!@```````````````@`````````"````6V____X`````````
M`@```````!BP````````&+``````````<`````<````"``````````@`````
M`````````&H````$``````````(````````9(````````!D@`````````Q@`
M```&```````````````(`````````!@```!T````!`````````!"````````
M'#@````````<.`````````6(````!@```!<`````````"``````````8````
M?@````$`````````!@```````"'`````````(<``````````0```````````
M``````````0``````````````'D````!``````````8````````B````````
M`"(`````````!X`````````````````````$`````````"````"$`````0``
M```````&````````*8`````````I@````````#SH````````````````````
M"```````````````B@````$`````````!@```````&9H````````9F@`````
M````+`````````````````````0``````````````)`````!``````````(`
M``````!FF````````&:8````````0&@````````````````````(````````
M``````"8`````0`````````"````````IP````````"G``````````#4````
M````````````````!```````````````I@````$``````````@```````*?8
M````````I]@````````%*`````````````````````@``````````````+``
M```.``````````,```````"]2````````*U(``````````@`````````````
M```````(``````````@```"\````#P`````````#````````O5````````"M
M4``````````(````````````````````"``````````(````R`````8`````
M`````P```````+U8````````K5@````````"(`````<```````````````@`
M````````$````-$````!``````````,```````"_>````````*]X````````
M`(@````````````````````(``````````@```#6`````0`````````#````
M````P`````````"P``````````'8````````````````````"```````````
M````WP````$``````````P```````,'8````````L=@`````````N```````
M``````````````@``````````````.4````(``````````,```````#"D```
M`````+*0````````$#`````````````````````(``````````````#J````
M`0`````````P``````````````````"RD``````````8````````````````
M`````0`````````!`````0````,`````````````````````````````LJ@`
?````````\P````````````````````$`````````````
